==> jc-1.4.0.tar.gz: polyglot/frontend/Pass.h <==
// public abstract interface polyglot.frontend.Pass

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 82f7472f39b4803b polyglot_frontend_Pass

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_polyglot_frontend_Pass_H_
#define _JC_polyglot_frontend_Pass_H_

// Typedefs
typedef struct _jc_polyglot_frontend_Pass$fields_struct	_jc_polyglot_frontend_Pass$fields_struct;
typedef const struct _jc_polyglot_frontend_Pass$vtype	_jc_polyglot_frontend_Pass$vtype;

// Class fields structure
struct _jc_polyglot_frontend_Pass$fields_struct {
	struct _jc_polyglot_frontend_Pass__24ID$object	*ADD__5fMEMBERS;
	struct _jc_polyglot_frontend_Pass__24ID$object	*ADD__5fMEMBERS__5fALL;
	struct _jc_polyglot_frontend_Pass__24ID$object	*BUILD__5fTYPES;
	struct _jc_polyglot_frontend_Pass__24ID$object	*BUILD__5fTYPES__5fALL;
	struct _jc_polyglot_frontend_Pass__24ID$object	*CLEAN__5fSIGS;
	struct _jc_polyglot_frontend_Pass__24ID$object	*CLEAN__5fSUPER;
	struct _jc_polyglot_frontend_Pass__24ID$object	*CLEAN__5fSUPER__5fALL;
	struct _jc_polyglot_frontend_Pass__24ID$object	*CONSTRUCTOR__5fCHECK;
	struct _jc_polyglot_frontend_Pass__24ID$object	*DISAM;
	struct _jc_polyglot_frontend_Pass__24ID$object	*DISAM__5fALL;
	struct _jc_polyglot_frontend_Pass__24ID$object	*DUMP;
	struct _jc_polyglot_frontend_Pass__24ID$object	*EXC__5fCHECK;
	struct _jc_polyglot_frontend_Pass__24ID$object	*EXIT__5fCHECK;
	struct _jc_polyglot_frontend_Pass__24ID$object	*FIRST__5fBARRIER;
	struct _jc_polyglot_frontend_Pass__24ID$object	*FOLD;
	struct _jc_polyglot_frontend_Pass__24ID$object	*INIT__5fCHECK;
	struct _jc_polyglot_frontend_Pass__24ID$object	*OUTPUT;
	struct _jc_polyglot_frontend_Pass__24ID$object	*PARSE;
	struct _jc_polyglot_frontend_Pass__24ID$object	*PRE__5fOUTPUT__5fALL;
	struct _jc_polyglot_frontend_Pass__24ID$object	*REACH__5fCHECK;
	struct _jc_polyglot_frontend_Pass__24ID$object	*SERIALIZE;
	struct _jc_polyglot_frontend_Pass__24ID$object	*SET__5fEXPECTED__5fTYPES;
	struct _jc_polyglot_frontend_Pass__24ID$object	*TYPE__5fCHECK;
};
extern _jc_polyglot_frontend_Pass$fields_struct _jc_polyglot_frontend_Pass$class_fields;

// Static methods
extern void _jc_polyglot_frontend_Pass$method$_clinit$a816641e0ba8bfef(_jc_env *);

// Vtype
struct _jc_polyglot_frontend_Pass$vtype {
	_jc_type			type;
};

// Type structure
extern _jc_polyglot_frontend_Pass$vtype _jc_polyglot_frontend_Pass$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_frontend_Pass, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_frontend_Pass$class_object;

#endif	/* _JC_polyglot_frontend_Pass_H_ */

==> jc-1.4.6.tar.gz: polyglot/frontend/Pass.h <==
// public abstract interface polyglot.frontend.Pass

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 82f7472f39b4803b polyglot_frontend_Pass

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_polyglot_frontend_Pass_H_
#define _JC_polyglot_frontend_Pass_H_

// Typedefs
typedef struct _jc_polyglot_frontend_Pass$fields_struct	_jc_polyglot_frontend_Pass$fields_struct;
typedef const struct _jc_polyglot_frontend_Pass$vtype	_jc_polyglot_frontend_Pass$vtype;

// Class fields structure
struct _jc_polyglot_frontend_Pass$fields_struct {
	struct _jc_polyglot_frontend_Pass__24ID$object	*ADD__5fMEMBERS;
	struct _jc_polyglot_frontend_Pass__24ID$object	*ADD__5fMEMBERS__5fALL;
	struct _jc_polyglot_frontend_Pass__24ID$object	*BUILD__5fTYPES;
	struct _jc_polyglot_frontend_Pass__24ID$object	*BUILD__5fTYPES__5fALL;
	struct _jc_polyglot_frontend_Pass__24ID$object	*CLEAN__5fSIGS;
	struct _jc_polyglot_frontend_Pass__24ID$object	*CLEAN__5fSUPER;
	struct _jc_polyglot_frontend_Pass__24ID$object	*CLEAN__5fSUPER__5fALL;
	struct _jc_polyglot_frontend_Pass__24ID$object	*CONSTRUCTOR__5fCHECK;
	struct _jc_polyglot_frontend_Pass__24ID$object	*DISAM;
	struct _jc_polyglot_frontend_Pass__24ID$object	*DISAM__5fALL;
	struct _jc_polyglot_frontend_Pass__24ID$object	*DUMP;
	struct _jc_polyglot_frontend_Pass__24ID$object	*EXC__5fCHECK;
	struct _jc_polyglot_frontend_Pass__24ID$object	*EXIT__5fCHECK;
	struct _jc_polyglot_frontend_Pass__24ID$object	*FIRST__5fBARRIER;
	struct _jc_polyglot_frontend_Pass__24ID$object	*FOLD;
	struct _jc_polyglot_frontend_Pass__24ID$object	*INIT__5fCHECK;
	struct _jc_polyglot_frontend_Pass__24ID$object	*OUTPUT;
	struct _jc_polyglot_frontend_Pass__24ID$object	*PARSE;
	struct _jc_polyglot_frontend_Pass__24ID$object	*PRE__5fOUTPUT__5fALL;
	struct _jc_polyglot_frontend_Pass__24ID$object	*REACH__5fCHECK;
	struct _jc_polyglot_frontend_Pass__24ID$object	*SERIALIZE;
	struct _jc_polyglot_frontend_Pass__24ID$object	*SET__5fEXPECTED__5fTYPES;
	struct _jc_polyglot_frontend_Pass__24ID$object	*TYPE__5fCHECK;
};
extern _jc_polyglot_frontend_Pass$fields_struct _jc_polyglot_frontend_Pass$class_fields;

// Static methods
extern void _jc_polyglot_frontend_Pass$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;

// Vtype
struct _jc_polyglot_frontend_Pass$vtype {
	_jc_type			type;
};

// Type structure
extern _jc_polyglot_frontend_Pass$vtype _jc_polyglot_frontend_Pass$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_frontend_Pass, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_frontend_Pass$class_object;

#endif	/* _JC_polyglot_frontend_Pass_H_ */
